Stan Math Library: stan/math/prim/scal/meta/is_vector_like.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

is_vector_like.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_IS_VECTOR_LIKE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_IS_VECTOR_LIKE_HPP
3
4 #include <stan/math/prim/scal/meta/is_vector.hpp>
5
6 namespace stan {
7
20 template <typename T>
21 struct is_vector_like {
22 enum { value = stan::is_vector<T>::value };
23 };
24
35 template <typename T>
36 struct is_vector_like<T*> {
37 enum { value = true };
38 };
39
40
53 template <typename T>
54 struct is_vector_like<const T> {
55 enum { value = stan::is_vector_like<T>::value };
56 };
57 }
58 #endif
59
stan::is_vector_like
Template metaprogram indicates whether a type is vector_like.
Definition: is_vector_like.hpp:21
stan
Definition: log_sum_exp.hpp:8
is_vector.hpp
stan::is_vector
Definition: is_vector.hpp:10
stan::is_vector_like::value
Definition: is_vector_like.hpp:22

[ Stan Home Page ] © 2011–2016, Stan Development Team.